<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spenden</translation>
    </message>
    <message>
        <source>Flattr</source>
        <translation>Flattr</translation>
    </message>
    <message>
        <source>Thanks to</source>
        <translation>Danke an</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
</context>
<context>
    <name>Albums</name>
    <message>
        <source>Albums</source>
        <translation>Alben</translation>
    </message>
</context>
<context>
    <name>Artists</name>
    <message>
        <source>Artists</source>
        <translation>Interpreten</translation>
    </message>
</context>
<context>
    <name>AudioLibrary</name>
    <message>
        <source>Artists</source>
        <translation>Interpreten</translation>
    </message>
    <message>
        <source>Albums</source>
        <translation>Alben</translation>
    </message>
    <message>
        <source>Titles</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Audio Library</source>
        <translation>Musikbibliothek</translation>
    </message>
</context>
<context>
    <name>AudioPlaylist</name>
    <message>
        <source>Now Playing</source>
        <translation>Jetzt gespielt</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Playlist</source>
        <translation>Abspielliste</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Remove from playlist</source>
        <translation>Aus Liste entfernen</translation>
    </message>
    <message>
        <source>Clear playlist</source>
        <translation>Liste löschen</translation>
    </message>
</context>
<context>
    <name>AuthenticationDialog</name>
    <message>
        <source>Authentication</source>
        <translation>Authentifizierung</translation>
    </message>
    <message>
        <source>XBMC on %1 requires authentication:</source>
        <translation>XBMC auf %1 verlangt authentifizierung:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
</context>
<context>
    <name>AuthenticationSheet</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>XBMC on %1 requires authentication:</source>
        <translation>XBMC auf %1 verlangt authentifizierung:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Passwort:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Benutzername:</translation>
    </message>
</context>
<context>
    <name>ConnectDialog</name>
    <message>
        <source>Host:</source>
        <translation>Rechner:</translation>
    </message>
    <message>
        <source>MAC Address (optional):</source>
        <translation>MAC Adresse (optional):</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Add Host</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Remove Host</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>HTTP Port:</translation>
    </message>
    <message>
        <source>Connect to XBMC</source>
        <translation>Verbinde mit XBMC</translation>
    </message>
    <message>
        <source>Searching for XBMC hosts.</source>
        <translation>Suche XBMC.</translation>
    </message>
    <message>
        <source>Please enable the following options in the Network settings of XBMC:</source>
        <translation>Bitte aktivieren Sie die folgenden Funktionen in den XBMC-Netzwerkeinstellungen:</translation>
    </message>
    <message>
        <source>If you don&apos;t use Zeroconf, add a host manually.</source>
        <translation>Wenn Sie Zeroconf nicht benutzen, fügen Sie den Ihr XBMC manuell hinzu.</translation>
    </message>
    <message>
        <source>Allow control of XBMC via HTTP</source>
        <translation>Steuerung über Webinterface zulassen</translation>
    </message>
    <message>
        <source>Allow programs on other systems to control XBMC</source>
        <translation>Stuerung über entfernte Programme zulassen</translation>
    </message>
    <message>
        <source>Announce these services to other systems via Zeroconf</source>
        <translation>Zeroconf-Veröffentlichung</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
</context>
<context>
    <name>ConnectionSheet</name>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>XBMC on %1</source>
        <translation>XBMC auf %1</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Rechner:</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>HTTP Port:</translation>
    </message>
    <message>
        <source>Remove Host</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <source>Add Host</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>MAC Address for WakeOnLan (optional):</source>
        <translation>MAC Adresse (optional):</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <source>Searching for XBMC hosts.</source>
        <translation>Suche XBMC.</translation>
    </message>
    <message>
        <source>Please enable the following options in the Network settings of XBMC:</source>
        <translation>Bitte aktivieren Sie die folgenden Funktionen in den XBMC-Netzwerkeinstellungen:</translation>
    </message>
    <message>
        <source>If you don&apos;t use Zeroconf, add a host manually.</source>
        <translation>Wenn Sie Zeroconf nicht benutzen, fügen Sie den Ihr XBMC manuell hinzu.</translation>
    </message>
    <message>
        <source>Allow control of XBMC via HTTP</source>
        <translation>Steuerung über Webinterface zulassen</translation>
    </message>
    <message>
        <source>Allow programs on other systems to control XBMC</source>
        <translation>Stuerung über entfernte Programme zulassen</translation>
    </message>
    <message>
        <source>Announce these services to other systems via Zeroconf</source>
        <translation>Zeroconf-Veröffentlichung</translation>
    </message>
</context>
<context>
    <name>Episodes</name>
    <message>
        <source>Episodes</source>
        <translation>Episoden</translation>
    </message>
</context>
<context>
    <name>HomeMenu</name>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothek</translation>
    </message>
</context>
<context>
    <name>ItemDetails</name>
    <message>
        <source>Rating:</source>
        <translation>Bewertung:</translation>
    </message>
    <message>
        <source>Episode:</source>
        <translation>Folge:</translation>
    </message>
    <message>
        <source>First aired:</source>
        <translation>Erstausstrahlung:</translation>
    </message>
    <message>
        <source>Genre:</source>
        <translation>Genre:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Jahr:</translation>
    </message>
    <message>
        <source>Director:</source>
        <translation>Direktor:</translation>
    </message>
    <message>
        <source>Tagline:</source>
        <translation>Titelzeile:</translation>
    </message>
    <message>
        <source>MPAA:</source>
        <translation>Altersfreigabe:</translation>
    </message>
    <message>
        <source>Instrument:</source>
        <translation>Instrument:</translation>
    </message>
    <message>
        <source>Style:</source>
        <translation>Stil:</translation>
    </message>
    <message>
        <source>Mood:</source>
        <translation>Stimmung:</translation>
    </message>
    <message>
        <source>Born:</source>
        <translation>Geboren:</translation>
    </message>
    <message>
        <source>Formed:</source>
        <translation>Formiert:</translation>
    </message>
    <message>
        <source>Died:</source>
        <translation>Gestorben:</translation>
    </message>
    <message>
        <source>Disbanded:</source>
        <translation>Auflösung:</translation>
    </message>
    <message>
        <source>Duration:</source>
        <translation>Dauer:</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Kommentar:</translation>
    </message>
    <message>
        <source>Playcount:</source>
        <translation>Zähler:</translation>
    </message>
    <message>
        <source>Cast:</source>
        <translation>Besetzung:</translation>
    </message>
    <message>
        <source>Season:</source>
        <translation>Staffel:</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation>Zur Playliste</translation>
    </message>
</context>
<context>
    <name>LibraryView</name>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Add to playlist</source>
        <translation>Zur Playliste</translation>
    </message>
    <message>
        <source>Rescan library</source>
        <translation>Bibliothek aktualisieren</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
</context>
<context>
    <name>MainPage</name>
    <message>
        <source>Music</source>
        <translation>Musik</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <source>Library</source>
        <translation>Bibliothek</translation>
    </message>
    <message>
        <source>Files</source>
        <translation>Dateien</translation>
    </message>
    <message>
        <source>Show files</source>
        <translation>Zeige Dateien</translation>
    </message>
    <message>
        <source>Show library</source>
        <translation>Zeige Bibliothek</translation>
    </message>
    <message>
        <source>Rescan library</source>
        <translation>Bibliothek aktualisieren</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Connect...</source>
        <translation>Verbinden...</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Incoming call</source>
        <translation>Eingehender Anruf</translation>
    </message>
</context>
<context>
    <name>MeeGoHelper</name>
    <message>
        <source>Incoming call</source>
        <translation>Eingehender Anruf</translation>
    </message>
</context>
<context>
    <name>Movies</name>
    <message>
        <source>Movies</source>
        <translation>Filme</translation>
    </message>
</context>
<context>
    <name>MusicVideos</name>
    <message>
        <source>Music Videos</source>
        <translation>Musikvideos</translation>
    </message>
</context>
<context>
    <name>NfcHandler</name>
    <message>
        <source>NFC tag is not compatible with Xbmcremote. In order to use it with Xbmcremote you need to write connection information to it.</source>
        <translation>NFC Tag ist nicht mit Xbmcremote kompatibel. Um dieses Tag mit Xbmcremote zu verwenden, müsses Sie es vorher beschreiben.</translation>
    </message>
    <message>
        <source>NFC tag is outdated. In order to use it with Xbmcremote you need to update it by rewriting connection information to it.</source>
        <translation>NFC Tag ist veraltet. Um dieses Tag weiterhin mit Xbmcremote zu verwenden, müsses Sie es erneut beschreiben.</translation>
    </message>
</context>
<context>
    <name>NoConnectionPage</name>
    <message>
        <source>Connect</source>
        <translation>Verbinden</translation>
    </message>
</context>
<context>
    <name>NowPlayingPage</name>
    <message>
        <source>Season:</source>
        <translation>Staffel:</translation>
    </message>
    <message>
        <source>Rating:</source>
        <translation>Bewertung:</translation>
    </message>
    <message>
        <source>Year:</source>
        <translation>Jahr:</translation>
    </message>
</context>
<context>
    <name>NowPlayingView</name>
    <message>
        <source>Now playing:</source>
        <translation>Jetzt gespielt:</translation>
    </message>
    <message>
        <source>Track:</source>
        <translation>Nummer:</translation>
    </message>
</context>
<context>
    <name>PlaylistPage</name>
    <message>
        <source>Play</source>
        <translation>Abspielen</translation>
    </message>
    <message>
        <source>Remove from playlist</source>
        <translation>Aus Abspielliste entfernen</translation>
    </message>
</context>
<context>
    <name>Seasons</name>
    <message>
        <source>Seasons</source>
        <translation>Staffeln</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Use Thumbnails</source>
        <translation>Benutze Vorschaubilder</translation>
    </message>
    <message>
        <source>Change volume during calls</source>
        <translation>Ändere Lautstärke währen Telefongesprächen</translation>
    </message>
    <message>
        <source>Pause video during calls</source>
        <translation>Pausiere Video währen Telefongesprächen</translation>
    </message>
    <message>
        <source>Pause music during calls</source>
        <translation>Pausiere Musik währen Telefongesprächen</translation>
    </message>
</context>
<context>
    <name>SettingsSheet</name>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Invert theme</source>
        <translation>Thema invertieren</translation>
    </message>
    <message>
        <source>Use Thumbnails</source>
        <translation>Vorschaubilder benutzen</translation>
    </message>
    <message>
        <source>Keep display on when charging</source>
        <translation>Bildschirm an wenn angesteckt</translation>
    </message>
    <message>
        <source>Look and feel</source>
        <translation>Erscheinungsbild</translation>
    </message>
    <message>
        <source>Phone calls</source>
        <translation>Telefongespräche</translation>
    </message>
    <message>
        <source>Change volume</source>
        <translation>Ändere Lautstärke</translation>
    </message>
    <message>
        <source>Pause video</source>
        <translation>Pausiere Videos</translation>
    </message>
    <message>
        <source>Pause music</source>
        <translation>Pausiere Musik</translation>
    </message>
</context>
<context>
    <name>Shares</name>
    <message>
        <source>Music Files</source>
        <translation>Musikdateien</translation>
    </message>
    <message>
        <source>Video Files</source>
        <translation>Videodateien</translation>
    </message>
    <message>
        <source>Picture Files</source>
        <translation>Bilder</translation>
    </message>
</context>
<context>
    <name>Songs</name>
    <message>
        <source>Songs</source>
        <translation>Lieder</translation>
    </message>
</context>
<context>
    <name>TvShows</name>
    <message>
        <source>TV Shows</source>
        <translation>TV Sendungen</translation>
    </message>
</context>
<context>
    <name>VideoLibrary</name>
    <message>
        <source>Video Library</source>
        <translation>Videothek</translation>
    </message>
    <message>
        <source>Movies</source>
        <translation>Filme</translation>
    </message>
    <message>
        <source>TV Shows</source>
        <translation>TV Sendungen</translation>
    </message>
    <message>
        <source>Music Videos</source>
        <translation>Musikvideos</translation>
    </message>
</context>
<context>
    <name>VideoPlaylist</name>
    <message>
        <source>Now Playing</source>
        <translation>Jetzt gespielt</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
</context>
<context>
    <name>WriteNfcTagSheet</name>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Tap a NFC tag to write XBMC connection information to it. You can then use the tag to connect to this XBMC.</source>
        <translation>Berühren Sie ein NFC Tag um Verbindungsinformationen darauf zu speichern. Danach können Sie es zum Verbinden benutzen.</translation>
    </message>
    <message>
        <source>Write NFC Tag</source>
        <translation>NFC Tag schreiben</translation>
    </message>
    <message>
        <source>Tag written successfully.</source>
        <translation>Tag erfolgreich beschrieben.</translation>
    </message>
</context>
<context>
    <name>XbmcConnection::XbmcConnectionPrivate</name>
    <message>
        <source>Connecting to %1...</source>
        <translation>Verbinde zu %1...</translation>
    </message>
    <message>
        <source>The connection has been disconnected</source>
        <translation>Die Verbindung wurde unterbrochen</translation>
    </message>
    <message>
        <source>Connection failed: %1</source>
        <translation>Verbindung fehlgeschlagen: %1</translation>
    </message>
    <message>
        <source>Connection to %1 timed out...</source>
        <translation>Zeitüberschreitung bei Verbindung zu %1...</translation>
    </message>
    <message>
        <source>Xbmcremote is designed to work with XBMC Eden (v11.0). It seems you have connected to an older version of XMBC. Please upgrade XBMC in order to use Xbmcremote.</source>
        <translation>Xbmcremote funktioniert nur mit XBMC Eden (v11.0). Sie haben sich zu einer älteren Version von XBMC verbunden. Bitte aktualisieren Sie XBMC um Xbmcremote zu verwenden.</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Connect...</source>
        <translation>Verbinden...</translation>
    </message>
    <message>
        <source>Write NFC Tag</source>
        <translation>NFC Tag schreiben</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Über</translation>
    </message>
    <message>
        <source>Quit xbmc</source>
        <translation>XBMC Beenden</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Herunterfahren</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Neustart</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Ruhezustand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Tiefschlaf</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>Copyright</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Schließen</translation>
    </message>
    <message>
        <source>Donate</source>
        <translation>Spenden</translation>
    </message>
    <message>
        <source>Flattr</source>
        <translation>Flattr</translation>
    </message>
</context>
</TS>
